@@ -1,6 +1,8 @@
 import time
 import inspect
 import uuid
+import atexit
+import asyncio
 
 import requests
 
@@ -9,6 +11,11 @@ from flask import current_app, request, jsonify, abort
 from nacl.exceptions import BadSignatureError
 from nacl.signing import VerifyKey
 
+try:
+    import aiohttp
+except ImportError:
+    aiohttp = None
+
 from flask_discord_interactions.command import SlashCommand, SlashCommandGroup
 from flask_discord_interactions.context import Context
 from flask_discord_interactions.response import Response, ResponseType
@@ -479,6 +486,9 @@ class DiscordInteractions(DiscordInteractionsBlueprint):
         Add a route handler to a Quart app that handles incoming interaction
         data using asyncio.
 
+        This function also sets up the aiohttp ClientSession that is used
+        for sending followup messages, etc.
+
         Parameters
         ----------
         route
@@ -490,6 +500,11 @@ class DiscordInteractions(DiscordInteractionsBlueprint):
         if app is None:
             app = self.app
 
+        if aiohttp == None:
+            raise ImportError(
+                "The aiohttp module is required for async usage of this "
+                "library")
+
         @app.route(route, methods=["POST"])
         async def interactions():
             self.verify_signature(request)
@@ -507,3 +522,26 @@ class DiscordInteractions(DiscordInteractionsBlueprint):
                 result = await result
 
             return jsonify(result.dump())
+
+        # Set up the aiohttp ClientSession
+
+        async def create_session():
+            app.discord_client_session = aiohttp.ClientSession(
+                headers=self.auth_headers(app),
+                raise_for_status=True
+            )
+
+        async def close_session():
+            await app.discord_client_session.close()
+
+        if hasattr(app, "before_serving"):
+            # Quart apps
+            app.before_serving(create_session)
+            app.after_serving(close_session)
+        else:
+            # Flask apps
+            app.before_first_request(create_session)
+            atexit.register(
+                lambda: asyncio.get_event_loop().run_until_complete(
+                    close_session())
+            )
